import execa from 'execa';
export { execa };
export declare function exec(command: string, options?: execa.Options): execa.ExecaChildProcess;
export declare function exec(commands: string[], options?: execa.Options): Promise<execa.ExecaReturns[]>;
export declare const spawn: execa.ExecaStatic;
export declare class ShellContext {
    private _cwdStack;
    private _env;
    logCommand: boolean;
    sleep: (ms: number) => Promise<void>;
    /**
     * get current word directory
     */
    readonly cwd: string;
    private readonly _logger;
    /**
     * change work directory
     * @param dir
     */
    cd(dir: string): this;
    /**
     * like pushd in shell
     * @param dir
     */
    pushd(dir: string): this;
    /**
     * like popd in shell
     */
    popd(): this;
    /**
     * execute command(s)
     * @param command
     * @param options
     */
    exec(command: string, options?: execa.Options): execa.ExecaChildProcess;
    exec(commands: string[], options?: execa.Options): Promise<execa.ExecaReturns[]>;
    /**
     * spawn file
     * @param file
     * @param args
     * @param options
     */
    spawn(file: string, args?: string[], options?: execa.Options): execa.ExecaChildProcess;
    /**
     * set/get/delete env
     * set: ctx.env('key', 'val')
     * get: ctx.env('key')
     * delete: ctx.env('key', void 0)
     * @param key
     */
    env(key: string): string | undefined;
    env(key: string, val: string | undefined): this;
    /**
     * reset env to default
     */
    resetEnv(): this;
    private _logCmd;
}
export declare function shell(callback: (ctx: ShellContext) => Promise<any>): Promise<any>;
