"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const util_1 = tslib_1.__importDefault(require("util"));
const strip_ansi_1 = tslib_1.__importDefault(require("strip-ansi"));
exports.LogLevels = {
    debug: 0,
    info: 1,
    warn: 2,
    error: 3,
};
function makeLogger(level, logger) {
    return (...args) => {
        const { _props: props } = logger;
        let levelNum = exports.LogLevels[level];
        let filterLevelNum = exports.LogLevels[props.level || 'debug'];
        let message = props.format(level, props.levelColor[level], args);
        if (levelNum >= filterLevelNum && !props.hideConsole) {
            console.log(message);
        }
        props.onLog &&
            props.onLog({
                level,
                message: strip_ansi_1.default(message),
                levelNum,
                filter: filterLevelNum,
                args,
            });
    };
}
class Logger {
    constructor(_props = {}) {
        this.debug = makeLogger('debug', this);
        this.info = makeLogger('info', this);
        this.log = makeLogger('info', this);
        this.warn = makeLogger('warn', this);
        this.error = makeLogger('error', this);
        this._props = Object.assign({}, Logger.defaultProps, _props);
    }
    static get defaultProps() {
        return {
            levelColor: {
                debug: chalk_1.default.blueBright,
                info: chalk_1.default.green,
                warn: chalk_1.default.yellow,
                error: chalk_1.default.red,
            },
            format(level, color, args) {
                return `${color(`[${level}]`)} ${args
                    .map(a => typeof a === 'string' ? a : util_1.default.inspect(a, false, 5))
                    .join(' ')}`;
            },
            level: 'debug',
        };
    }
}
exports.Logger = Logger;
exports.logger = new Logger();
//# sourceMappingURL=logger.js.map